open_wave_file_with_format

Function open_wave_file_with_format 

pub fn open_wave_file_with_format(
    path: &Path,
    options: &NameOptions,
    format: Option<WaveFormat>,
) -> Result<(WaveReader, WaveHierarchy), String>
Open a waveform file, optionally forcing a specific format.

When format is None, the format is auto-detected from file contents. When format is Some(WaveFormat::Fst) or Some(WaveFormat::Vcd), that format is used directly and the error message reflects the specific format.